#
# spec file for package perl-ExtUtils-F77
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-ExtUtils-F77
Version:        1.20
Release:        bp153.1.14
%define cpan_name ExtUtils-F77
Summary:        Simple interface to F77 libs
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/ExtUtils-F77/
Source0:        https://cpan.metacpan.org/authors/id/C/CH/CHM/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gcc-fortran
BuildRequires:  gmp-devel
# MANUAL END

%description
This module tries to figure out how to link C programs with Fortran
subroutines on your system. Basically one must add a list of Fortran
runtime libraries. The problem is their location and name varies with each
OS/compiler combination!

This module tries to implement a simple 'rule-of-thumb' database for
various flavours of UNIX systems. A simple self-documenting Perl database
of knowledge/code for figuring out how to link for various combinations of
OS and compiler is embedded in the modules Perl code. Please help save the
world by sending database entries for your system to karl_pgplot@mac.com

Note the default on most systems is now to search for a generic 'GNU'
compiler which can be g77, gfortran or g95 and then find the appropriate
link libraries automatically. (This is the 'Generic' 'GNU' database entry
in the code.)

The library list which the module returns can be explicitly overridden by
setting the environment variable F77LIBS, e.g.

  % setenv F77LIBS "-lfoo -lbar"
  % perl Makefile.PL
  ...

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc CHANGES README
%license COPYING

%changelog
* Mon Oct 16 2017 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-ExtUtils-F77/CHANGES
  v1.20 released May 28th 2016
  - -----------------------------
  * Apply upstream FreeBSD patch thanks to srezic for submitting
  * Fix fallback compiler logic to support gcc-5.x and higher
  * Limited Improved gfortran linking on OS X Yosemite+ to OS X
  v1.19_3 released May 28th 2016
  - -----------------------------
  * Apply upstream FreeBSD patch thanks to srezic for submitting
  v1.19_2 released May 28th 2016
  - -----------------------------
  * Fix fallback compiler logic to support gcc-5.x and higher
  v1.19_1 released Mar 6th 2016
  - ---------------------------
  * Limited Improved gfortran linking on OS X Yosemite+ to OS X
  v1.19 released Dec 12th 2015
  - ---------------------------
  * Improved gfortran linking on OS X Yosemite+ which avoids PERL_DL_NONLAZY meltdowns
  v1.18 released Jul 7th 2015
  - --------------------------
  * resolve rt.cpan.org bug #104495: MinGW now needs to link to libquadmath.a
    Thanks for the patch, kmx.
  v1.17_01 released Jul 6th 2014
  - -----------------------------
  * Graham Bell's fix to "Add check for GNU fortran .so files as well as .a."
  * Typo fix by dsteinbrunner
  * Fix Cygwin table to use Generic GNU settings
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Fri Jan  7 2011 vcizek@novell.com
- update to 1.17
  * Derek Lamb's patch to avoid an uninitialised variable error.
  * Diab Jarius's Solaris Studio 10 patch and his gfortran patch (with mods).
  Note g77 is still the default if both it and gfortran are present.
  * Rob's big Win32 patch (Nov 2010 version)
  * ** IMPORTANT. Added in simplification of GNU fortran compilers (g77, gfortran, g95, fort77)
  etc. suggested by Tim Jeness. I used his code but made a slightly different
  implementaion introducing a 'Generic' 'GNU' database entry to which others point.
  This also superceded some of the above patches.
  * Removed places where .gcclibs() is added to the link line, this appears to no loner
  be necessary. Routine left in there (but orphaned) just in case.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.16
  * Added new config entry for Darwin/OSX (using gcc 4.0 and g77,
    gfortran or g95)
  * Added new entry for gfortran under Linux
  * Works fine under g77 on intel Mac OS X.
- remove our gfortran patch, fixed in upstream
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Jan 13 2006 anicka@suse.cz
- update to 1.15
* Mon Apr 18 2005 mjancar@suse.de
- fix for gcc 4.0
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Jan 16 2002 rvasice@suse.cz
- initial package release (version 1.14)
